pub enum CalcError {
NameNotFound(String),
NameAlreadyBound(String),
IncorrectArity(usize, usize),
ParseNum,
ParseError,
IOError,
Unknown,
}Expand description
The error type returned when functions in this crate go wrong.
Variants
NameNotFound(String)
Symbol is not in context.
NameAlreadyBound(String)
Use tried to assign a value to a name that already has a value assigned to it.
IncorrectArity(usize, usize)
Function called with incorrect number of arguments. IncorrectArity(expected, found).
ParseNum
There was an error when parsing a number.
ParseError
There was a parsing error.
IOError
An error with IO like stdin not working.
Unknown
Error in astro_float.